<?php
/* $Id: japanese-sjis.inc.php,v 2.80 2005/08/19 17:01:49 lem9 Exp $ */

/**
 * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
 *               Tadashi Jokagi <elf2000 at users.sourceforge.net>
 */

$charset = 'shift_jis';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = '"MS PGochic", Osaka, verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = '"MS PGochic", Osaka, arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('oCg', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('', '', '', '', '', '', 'y');
$month = array('1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 ');
// See http://www.php.net/manual/ja/function.strftime.php to define the
// variable below
$datefmt = '%Y N %B %d  %H:%M';
$timespanfmt = '%s  %s  %s  %s b';

$strAPrimaryKey = 'L[ %s ɒǉ܂B';
$strAbortedClients = 'f';
$strAbsolutePathToDocSqlDir = 'docSQL ւ̐΃pXݒ肵ĂB';
$strAccessDenied = 'ANZX͋ۂ܂B';
$strAccessDeniedExplanation = 'phpMyAdmin ́AMySQL T[o[ɐڑ悤Ƃ܂BāAT[o[͐ڑ₵܂Bconfig.inc.php ̒̃zXgA[U[уpX[h`FbNAMySQL T[o[̊Ǘl^ꂽɂ炪邱Ƃm߂ׂłB';
$strAction = 's';
$strAddAutoIncrement = 'uAUTO_INCREMENTvlǉ';
$strAddConstraints = 'ǉ';
$strAddDeleteColumn = 'tB[h́uǉ/폜v';
$strAddDeleteRow = 'śuǉ/폜v';
$strAddDropDatabase = 'uDROP DATABASEvǉ';
$strAddFields = '%s ̃tB[hǉ';
$strAddHeaderComment = 'wb_[փJX^Rgǉ (\\n ŉs)';
$strAddIfNotExists = 'uIF NOT EXISTSvǉ';
$strAddIntoComments = 'Rgǉ';
$strAddNewField = 'tB[h̒ǉ';
$strAddPrivilegesOnDb = 'f[^x[X֓̒ǉ';
$strAddPrivilegesOnTbl = 'e[u֓̒ǉ';
$strAddSearchConditions = 'ǉĂB("where"̐ߕ):';
$strAddToIndex = ' &nbsp;%s&nbsp; ̗CfbNXɒǉ܂';
$strAddUser = '[U[̒ǉ';
$strAddUserMessage = '[U[ǉ܂B';
$strAddedColumnComment = 'J̃Rgǉ܂B';
$strAddedColumnRelation = 'J̃[Vǉ܂B';
$strAdministration = 'Ǘ';
$strAffectedRows = 'eꂽs:';
$strAfter = 'wJ̌ %s';
$strAfterInsertBack = '߂';
$strAfterInsertNewInsert = 'VR[hǉ';
$strAfterInsertNext = '̍sҏW';
$strAfterInsertSame = '̃y[Wɖ߂';
$strAll = 'S';
$strAllTableSameWidth = 'SẴe[u𓯂ŕ\܂?';
$strAlterOrderBy = 'e[uԂ̏';
$strAnIndex = 'CfbNX%sɒǉĂ܂B';
$strAnalyzeTable = 'e[u𕪐͂';
$strAnd = 'AND';
$strAny = 'S';
$strAnyHost = 'SẴzXg';
$strAnyUser = 'SẴ[U[';
$strApproximateCount = 'ߎ܂BFAQ 3.11 QƂĂB';
$strArabic = 'ArA';
$strArmenian = 'AjA';
$strAscending = '';
$strAtBeginningOfTable = 'e[u̐擪';
$strAtEndOfTable = 'e[u̖';
$strAttr = '\';
$strAutodetect = 'm';
$strAutomaticLayout = 'CAEg';

$strBack = '߂';
$strBaltic = 'og';
$strBeginCut = '؂Jn';
$strBeginRaw = 'RAW Jn';
$strBinLogEventType = 'Cxg^Cv';
$strBinLogInfo = '';
$strBinLogName = 'O';
$strBinLogOriginalPosition = '̈ʒu';
$strBinLogPosition = 'ʒu';
$strBinLogServerId = 'T[o[ ID';
$strBinary = ' oCi ';
$strBinaryDoNotEdit = ' oCi - Cł܂';
$strBinaryLog = 'oCiO';
$strBookmarkAllUsers = 'ׂẴ[U[̃ubN}[NANZXł';
$strBookmarkDeleted = 'ubN}[N𐳏ɍ폜܂B';
$strBookmarkLabel = 'x';
$strBookmarkOptions = 'ubN}[NIvV';
$strBookmarkQuery = 'ubN}[NĂ SQL Ɖ';
$strBookmarkThis = 'SQL ƉubN}[N';
$strBookmarkView = '\̂';
$strBrowse = '\';
$strBrowseForeignValues = 'OL[\';
$strBufferPool = 'obt@v[';
$strBufferPoolUsage = 'obt@v[̎gp';
$strBufferReadMisses = 'ǂݍ݃~X';
$strBufferReadMissesInPercent = '% ̓ǂݍ݃~X';
$strBufferWriteWaits = 'ݑ҂';
$strBufferWriteWaitsInPercent = '% ̏ݑ҂';
$strBulgarian = 'uKA';
$strBusyPages = 'rW[ȃy[W';
$strBzError = ' php o[W Bz2 gĂ̂ phpMyAdmin k_vł܂BphpMyAdmin ̃RtBO[Vt@C <code>$cfg[\'BZipDump\']</code>  <code>FALSE</code>ɐݒ肵ĂBBz2 k@\gꍇɂ php ̃o[WグĉBphp oO %s ڍׁB';
$strBzip = '"bzip "';

$strCSVOptions = 'CSV IvV';
$strCalendar = 'J_[';
$strCannotLogin = 'MySQL T[o[ɃOCł܂';
$strCantLoad = 'Ȃgq̃t@Cł,<br />PHP ̐ݒ`FbNĂB';
$strCantLoadRecodeIconv = 'Zbgϊs߂ɂ͑gݍ܂ĂȂ iconv ܂ GNU recode ̊gKvłBphp ɁÅgݒsĂAphpMyAdminł͕ZbgϊȂݒɂĂB';
$strCantRenameIdxToPrimary = 'CfbNX̖O PRIMARY ɕύXł܂B';
$strCantUseRecodeIconv = 'iconvAlibiconvArecode_string ̂ǂ̊֐gpł܂Bphp ̐ݒ`FbNĂB';
$strCardinality = 'J[fBieB';
$strCarriage = 'LbW^[: \\r';
$strCaseInsensitive = 'p̑召ʂȂ';
$strCaseSensitive = 'p̑召ʂ';
$strCentralEuropean = '[bpl';
$strChange = 'ύX';
$strChangeCopyMode = 'VK̃[U[...';
$strChangeCopyModeCopy = '... Â̂ێ';
$strChangeCopyModeDeleteAndReload = ' ... [U[e[uÂ̂폜AœɍĂу[h';
$strChangeCopyModeJustDelete = ' ... [U[e[uÂ̂폜';
$strChangeCopyModeRevoke = ' ... Â̂LȓׂĖɂAō폜';
$strChangeCopyUser = 'OCύX / [U[Rs[';
$strChangeDisplay = '\tB[hIŉ';
$strChangePassword = 'pX[h̕ύX';
$strCharset = 'Zbg';
$strCharsetOfFile = 't@C̕Zbg:';
$strCharsets = 'R[h';
$strCharsetsAndCollations = 'ZbgƏƉ';
$strCheckAll = 'SĂ}[N';
$strCheckOverhead = 'I[o[wbȟ';
$strCheckPrivs = '̃`FbN';
$strCheckPrivsLong = 'f[^x[X &quot;%s&quot; ̓`FbNB';
$strCheckTable = 'e[u`FbN';
$strChoosePage = 'ҏWy[WIĂB';
$strColComFeat = 'Rg\@\ ';
$strCollation = 'Ɖ';
$strColumnNames = '(J)';
$strColumnPrivileges = 'J ';
$strCommand = 'R}h';
$strComments = 'Rg';
$strCommentsForTable = 'COMMENTS FOR TABLE';
$strCompatibleHashing = 'MySQL&nbsp;4.0 ݊';
$strCompleteInserts = 'S INSERT 쐬';
$strCompression = 'k';
$strConfigFileError = 'phpMyAdmin RtBO[Vt@CǂݍނƂł܂! <br />@G[NAt@C܂B<br />̃NRtBO[Vt@C𒼐ړǂݍŁAphp ̃G[bZ[WmFĂB ̏ꍇA؂蕶Z~RYĂ܂B<br />󔒂̃y[WꂽSĂ܂sĂ܂B';
$strConfigureTableCoord = '%s e[ũJ[fBieBݒ肵Ă';
$strConnectionError = 'ڑł܂: ȐݒłB';
$strConnections = 'ڑ';
$strConstraintsForDumped = '_vς݃e[u̐';
$strConstraintsForTable = 'e[u̐';
$strCookiesRequired = '̓NbL[ĂKv܂B';
$strCopy = 'Rs[';
$strCopyDatabaseOK = 'f[^x[X %s  %s ɃRs[܂B';
$strCopyTable = 'e[u(database<b>.</b>table)ɃRs[:';
$strCopyTableOK = '%s e[u %s ɃRs[܂B';
$strCopyTableSameNames = 'e[uɃRs[ł܂!';
$strCouldNotKill = 'phpMyAdminXbh%sI邱Ƃł܂łBAɏIĂ܂B';
$strCreate = '쐬';
$strCreateDatabaseBeforeCopying = 'Rs[̑O CREATE DATABASE ';
$strCreateIndex = '&nbsp;%s&nbsp; ̗̃CfbNX쐬';
$strCreateIndexTopic = 'VCfbNX쐬';
$strCreateNewDatabase = 'V DB 쐬܂B';
$strCreateNewTable = '݂ DB ɐVe[u쐬 %s --> ';
$strCreatePage = 'VKy[W쐬';
$strCreatePdfFeat = 'PDF 쐬@\ ';
$strCreationDates = '쐬/XV/̓tǉ';
$strCriteria = 'i݊';
$strCroatian = 'NA`A';
$strCyrillic = 'LVA';
$strCzech = '`FR';
$strCzechSlovak = '`FR̃XoLA';

$strDBComment = 'f[^x[XRg: ';
$strDBCopy = 'f[^x[XRs[ Rs[:';
$strDBCopy = 'Lփf[^x[XRs[';
$strDBGContext = 'ReLXg';
$strDBGContextID = 'ReLXgID';
$strDBGHits = 'qbg';
$strDBGLine = 's';
$strDBGMaxTimeMs = 'ő厞(~b)';
$strDBGMinTimeMs = 'ŏ(~b)';
$strDBGModule = 'W[';
$strDBGTimePerHitMs = 'qbg(~b)';
$strDBGTotalTimeMs = 'v(~b)';
$strDBRename = 'Lփf[^x[XύX';
$strDanish = 'f}[N';
$strData = 'f[^';
$strDataDict = 'f[^';
$strDataOnly = 'f[^̂';
$strDataPages = 'f[^܂ރy[W';
$strDatabase = 'f[^x[X';
$strDatabaseEmpty = 'f[^x[Xł!';
$strDatabaseExportOptions = 'f[^x[XGNX|[gIvV';
$strDatabaseHasBeenDropped = 'f[^x[X %s 𐳏ɍ폜܂B';
$strDatabaseNoTable = '̃f[^x[X̓e[u܂ł܂!';
$strDatabases = 'f[^x[X';
$strDatabasesDropped = '%s f[^x[X͍폜܂B';
$strDatabasesStats = 'f[^x[X̓v';
$strDatabasesStatsDisable = 'v𖳌ɂ';
$strDatabasesStatsEnable = 'v';
$strDatabasesStatsHeavyTraffic = ': f[^x[Xv MySQL  WEBT[o[̊ԂŏdgtBbN邩܂B';
$strDbPrivileges = 'f[^x[X ';
$strDbSpecific = 'f[^x[Xdl';
$strDefault = '{l';
$strDefaultEngine = '%s ́A MySQL T[o[̃ftHgXg[WGWłB';
$strDefaultValueHelp = 'ftHgl̂߂ɁAobNXbVGXP[vpȂ 1 ̒lĉ, ̃tH[}bg: a';
$strDefragment = 'e[ũftO';
$strDelOld = '݂̃y[ẂA͂⑶݂Ȃe[uɎQƂ܂B̎QƂ폜ł?';
$strDelayedInserts = 'xCT[ggp';
$strDelete = '폜';
$strDeleteAndFlush = '[U[폜ē[h';
$strDeleteAndFlushDescr = '̓NA[łB[ĥŏXԂ܂B';
$strDeleted = 'I폜܂B';
$strDeletedRows = '폜ꂽs:';
$strDeleting = '%s 폜ł';
$strDescending = '~';
$strDescription = '';
$strDictionary = '';
$strDirtyPages = 'sȃy[W';
$strDisableForeignChecks = 'OL[̌𖳌ɂ';
$strDisabled = '';
$strDisplayFeat = 'e[u\@\ ';
$strDisplayOrder = '\:';
$strDisplayPDF = 'PDF XL[}̕\';
$strDoAQuery = '"QUERY"s (ChJ[h: "%")';
$strDoYouReally = '{ɎsĂǂłH --> ';
$strDocu = 'wv';
$strDrop = '폜';
$strDropSelectedDatabases = 'Iꂽf[^x[X̍폜';
$strDropUsersDb = '[U[ƓOf[^x[X폜';
$strDumpSaved = '_vt@C %s ɕۑ܂B';
$strDumpXRows = '%s _vBJn %s łB';
$strDumpingData = 'e[ũ_vf[^';
$strDynamic = '_Ci~bN';

$strEdit = 'C';
$strEditPDFPages = 'PDF ̕ҏW y[W';
$strEditPrivileges = 'C';
$strEffective = '';
$strEmpty = 'ɂ';
$strEmptyResultSet = 'MySQL̒lԂ܂B(Ⴆ΍sƂ).';
$strEnabled = 'L';
$strEncloseInTransaction = 'gUNVŃGNX|[g͂';
$strEncto = 'GR[fBO֕ϊ'; // encoding convert
$strEnd = 'Ō';
$strEndCut = '؂I';
$strEndRaw = 'RAW I';
$strEngineAvailable = '%s ́A MySQL T[o[ŗp\łB';
$strEngineDisabled = '%s ́A MySQL T[o[ł͖ɂĂ܂B';
$strEngineUnsupported = ' MySQL T[o[ %s Xg[WGWT|[gĂ܂B';
$strEngines = 'GW';
$strEnglish = 'p';
$strEnglishPrivileges = ' : MySQL̖̓O͉pŕ\Ă܂B';
$strError = 'G[';
$strEscapeWildcards = 'ChJ[hu_vсu%v͂𕶎ʂɎgp邽߂Ɂu\vŃGXP[v()ׂłB';
$strEscapeWildcards = 'ChJ[hu_vƁu%v́A𕶎ʂɎgp邽߂Ɂu\vŉKv܂B';
$strEstonian = 'GXgjA';
$strExcelEdition = 'Excel ̎';
$strExcelOptions = 'Excel IvV';
$strExecuteBookmarked = 'ubN}[NꂽƉs';
$strExplain = 'Explain SQL';
$strExport = 'GNX|[g';
$strExtendedInserts = ' INSERT 쐬';
$strExtra = 'ǉ';

$strFailedAttempts = 's܂';
$strField = 'tB[h';
$strFieldHasBeenDropped = 'tB[h %s ɍ폜܂';
$strFields = 'tB[h';
$strFieldsEmpty = ' tB[h͋łB ';
$strFieldsEnclosedBy = 'tB[h͂݋L';
$strFieldsEscapedBy = 'tB[h̃GXP[vL';
$strFieldsTerminatedBy = 'tB[h؂L';
$strFileAlreadyExists = 't@C %s ͊ɃT[o[ɑ݂܂Bt@CύX邩A㏑IvVmFĂB';
$strFileCouldNotBeRead = 't@Cǂ߂܂B';
$strFileNameTemplate = 't@C̃ev[g';
$strFileNameTemplateHelp = '__DB__ f[^x[XɁA__TABLE__ e[uɁA%sCӂ strftime ֐%s IvVԎdlɁAgƂĎIɒǉł傤B̃eLXgۑł傤B';
$strFileNameTemplateRemember = 'ev[go';
$strFixed = 'Œ';
$strFlushPrivilegesNote = ': phpMyAdmin  MySQL ̓e[u璼ڂɃ[U[𓾂܂B}jAœύXĂƁÃe[u̓eƂ͈قȂ邩܂B̏ꍇA܂ %s [h %s Kv܂B';
$strFlushTable = 'e[ũLbVɂ("FLUSH")';
$strFormEmpty = 'tH[ł͒l܂łB';
$strFormat = 'tH[}bg';
$strFreePages = 't[ȃy[W';
$strFullText = 'S';
$strFunction = '֐';

$strGenBy = 'ꂽ by';
$strGenTime = '쐬̎';
$strGeneralRelationFeat = '[V@\ ';
$strGenerate = '';
$strGeneratePassword = 'pX[h𐶐';
$strGeorgian = 'OWA';
$strGerman = 'hCc';
$strGlobal = 'O[o';
$strGlobalPrivileges = 'O[o';
$strGlobalValue = 'O[ol';
$strGo = 's';
$strGrantOption = 'Ϗ';
$strGreek = 'MVA';
$strGzip = '"gzip "';

$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 GNX|[gIvV';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 GNX|[gIvV';
$strHasBeenAltered = 'ύX܂B';
$strHasBeenCreated = '쐬܂B';
$strHaveToShow = '\邽߂ɁAȂĂЂƂ̃JIȂ΂Ȃ܂B';
$strHebrew = 'wuC';
$strHexForBinary = 'oCitB[h 16 igp';
$strHome = 'Cy[W';
$strHomepageOfficial = 'phpMyAdmin z[';
$strHost = 'zXg';
$strHostEmpty = 'zXg͋ł!';
$strHungarian = 'nK[';

$strIcelandic = 'ACXh';
$strId = 'ID';
$strIdxFulltext = 'S';
$strIfYouWish = 'e[u̗(J)Ƀf[^ǉꍇ́AtB[hꗗJ}ŋ؂ĂB';
$strIgnore = '';
$strIgnoreInserts = 'uINSERT IGNOREvgp';
$strIgnoringFile = 't@C𖳎 %s';
$strImportDocSQL = 'docSQL t@CC|[g';
$strImportFiles = 'C|[gt@C';
$strImportFinished = 'C|[gI܂';
$strInUse = 'gp';
$strIndex = 'CfbNX';
$strIndexHasBeenDropped = 'CfbNX %s 폜܂';
$strIndexName = 'CfbNX&nbsp;:';
$strIndexType = 'CfbNX̎&nbsp;:';
$strIndexWarningMultiple = '1 z INDEX L[J `%s` pɍ쐬܂B';
$strIndexWarningPrimary = 'PRIMARY  INDEX ̃L[͗ƂAJ `%s` ɐݒ肳ׂł͂܂B';
$strIndexWarningTable = 'e[u `%s` ̃CfbNXɊւ';
$strIndexWarningTable = 'e[u `%s` ̃CfbNXɊւłB';
$strIndexWarningUnique = 'UNIQUE  INDEX ̃L[͗ƂAJ `%s` ɐݒ肳ׂł͂܂B';
$strIndexes = 'CfbNXTCY';
$strInnoDBAutoextendIncrement = 'g̒ǉ';
$strInnoDBAutoextendIncrementDesc = ' ꂪςɂȂꍇɁAge[uXy[X̃TCYg邽߂̑ʂłB';
$strInnoDBBufferPoolSize = 'obt@[~σTCY';
$strInnoDBBufferPoolSizeDesc = 'InnoDB LbVf[^Ƃ̃e[ũCfbNXɎgobt@̃TCYłB';
$strInnoDBDataFilePath = 'f[^t@C';
$strInnoDBDataHomeDir = 'f[^z[fBNg';
$strInnoDBDataHomeDirDesc = 'ׂĂ InnoDB f[^t@Cp̃fBNgpX̋ʕłB';
$strInnoDBPages = 'y[W';
$strInnodbStat = 'InnoDB Xe[^X';
$strInsecureMySQL = 'Ȃ̃RtBO[Vt@C̐ݒ肪 MySQL ftHg̓AJEgɂȂĂ܂ (root [U[ŃpX[hȂ) B MySQL T[o[̃ftHgݒœ삵Ă̂ŁAN҂ɑ΂ĖhłB̃ZLeB[z[͕KĂB';
$strInsert = 'ǉ';
$strInsertAsNewRow = 'VsƂĒǉ';
$strInsertBookmarkTitle = 'ubN}[Ñ^Cg͂ĂB';
$strInsertNewRow = 'Vsǉ';
$strInsertTextfiles = 'e[uɃeLXgt@Cǉ';
$strInsertedRowId = 'CT[gs ID:';
$strInsertedRows = 'ǉꂽs:';
$strInstructions = '{';
$strInternalNotNecessary = '* InnoDB ݂ꍇA[V͕Kvł͂܂B';
$strInternalRelations = '[V';

$strJapanese = '{';
$strJumpToDB = '&quot;%s&quot; f[^x[XփWv.';
$strJustDelete = 'e[u烆[U[𑦍폜';
$strJustDeleteDescr = '&quot;폜&quot; [U[͓[h܂ŃT[o[ɃANZX\łB';

$strKanjiEncodConvert = 'R[hϊ'; // kanji code convert
$strKeepPass = 'pX[hύXȂ';
$strKeyname = 'L[';
$strKill = '~';
$strKorean = '؍';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX IvV';
$strLandscape = 'hXP[v';
$strLatexCaption = 'e[uLvV';
$strLatexContent = 'e[u __TABLE__ ̓e';
$strLatexContinued = '()';
$strLatexContinuedCaption = 'p̃e[uLvV';
$strLatexIncludeCaption = 'e[uLvV܂';
$strLatexLabel = 'xL[';
$strLatexStructure = 'e[u __TABLE__ ̍\';
$strLatvian = 'grA';
$strLengthSet = '/Zbg*';
$strLimitNumRows = 'y[W̍ő僌R[h';
$strLineFeed = 's: \\n';
$strLinesTerminatedBy = 's̏I[L';
$strLinkNotFound = 'N܂';
$strLinksTo = 'N';
$strLithuanian = 'gAjA';
$strLoadExplanation = 'ŗǂ̎i̓ftHg`FbNĂ܂BAꂪsꍇAύX邱Ƃł܂B';
$strLoadMethod = 'LOAD i';
$strLocalhost = '[J';
$strLocationTextfile = 'eLXgt@C̏ꏊ';
$strLogPassword = 'pX[h:';
$strLogServer = 'T[o[';
$strLogUsername = '[U[:';
$strLogin = 'OC';
$strLoginInformation = 'OC';
$strLogout = 'OAEg';
$strLongOperation = '͎̑Ԃ܂Błi݂܂?';

$strMIMETypesForTable = 'MIME TYPES FOR TABLE';
$strMIME_MIMEtype = 'MIME ^Cv';
$strMIME_available_mime = 'L MIME ^Cv';
$strMIME_available_transform = 'ϊL';
$strMIME_description = '';
$strMIME_transformation = 'uEU[ϊ';
$strMIME_transformation_note = 'p\ȕϊIvV̈ꗗAт MIME `ϊɊւẮA%sϊ̐%s NbNĂB';
$strMIME_transformation_options = 'ϊIvV';
$strMIME_without = 'C^bN̂ňꂽMIME ^Cv͌ʂ̕ϊ֐Ă܂B';
$strMaximumSize = 'őTCY: %s%s';
$strMbExtensionMissing = 'mbstring PHP g͌܂łB܂A}`oCgZbggpĂ悤Ɍ܂BphpMyAdmin  mbstring gȂł͕𐳊mɕ邱ƂłA܂A\ȂʂԂĂ邩܂B';
$strMbOverloadWarning = 'PHP ̐ݒ mbstring.func_overload LłB̃IvV phpMyAdmin ƌ݊ȂAf[^̔jN܂!';
$strModifications = '𐳂C܂B';
$strModify = 'C';
$strModifyIndexTopic = 'CfbNX̕ύX';
$strMoreStatusVars = '̑̕ϐ̏';
$strMoveTable = 'e[u(database<b>.</b>table)Ɉړ:';
$strMoveTableOK = 'e[u %s  %s ړ܂B';
$strMoveTableSameNames = 'e[uɈړł܂!';
$strMultilingual = '';
$strMustSelectFile = 'CT[gt@CIׂłB';
$strMyISAMDataPointerSize = 'f[^|C^[TCY';
$strMyISAMMaxExtraSortFileSize = 'CfbNX쐬pꎞt@C̍őTCY';
$strMyISAMMaxSortFileSize = 'ꎞ\[gt@C̍őTCY';
$strMyISAMMaxSortFileSizeDesc = 'MyISAM CfbNX̍č쐬Ŏgp邱Ƃꂽ MySQL ꎞt@C̍őTCYł (REPAIR TABLE AALTER TABLE  LOAD DATA INFILE)';
$strMyISAMRecoverOptions = 'C[h';
$strMyISAMRecoverOptionsDesc = 'NbV MyISAM e[u̎񕜗p[hŁAT[o[NIvV --myisam-recover Őݒ肵܂B';
$strMyISAMRepairThreads = 'yAXbh';
$strMyISAMRepairThreadsDesc = '̒l 1 ȏȂAMyISAM e[ũCfbNX̓\[g̏Cɕs(ꎩg̊eCfbNX)쐬܂B';
$strMyISAMSortBufferSize = '\[gobt@[TCY';
$strMyISAMSortBufferSizeDesc = '̃obt@[́AREPAIR TABLE ̊Ԃ MyISAM CfbNX\[gꍇA܂ CREATE INDEX  ALTER TABLE ƃCfbNX쐬ꍇɁAt܂B';
$strMySQLCharset = 'MySQL̕Zbg';
$strMySQLConnectionCollation = 'MySQL ڑƉ';
$strMySQLReloaded = 'MySQLVǂݍ݂܂B';
$strMySQLSaid = 'MySQL̃bZ[W --> ';
$strMySQLServerProcess = 'MySQL %pma_s1%  %pma_s2%  %pma_s3% ƂĎsĂ܂B';
$strMySQLShowProcess = 'MySQLvZX̕\';
$strMySQLShowStatus = 'MySQL̃^C';
$strMySQLShowVars = 'MySQL̃VXeϐ';

$strName = 'O';
$strNeedPrimaryKey = '̃e[u̓vC}L[`ׂł';
$strNext = '';
$strNo = '';
$strNoActivity = '%s bȏ㑀Ă܂BēxOCĂB';
$strNoDatabases = 'f[^x[X';
$strNoDatabasesSelected = 'f[^x[XIĂ܂B';
$strNoDescription = 'Lq܂';
$strNoDetailsForEngine = '̃Xg[WGWɂ͗LȃXe[^X̏ڍ׏͂܂B';
$strNoDropDatabases = '"DROP DATABASE"Xe[gg͋֎~';
$strNoExplain = 'Explain SQL XLbv';
$strNoFrames = 'phpMyAdmin <b>t[</b>T|[guEUł̗p߂܂B';
$strNoIndex = 'CfbNX͐ݒ肳Ă܂B';
$strNoIndexPartsDefined = 'CfbNX͐̕ݒ肳Ă܂B';
$strNoModification = 'ύX';
$strNoOptions = '̏̓IvV܂B';
$strNoPassword = 'pX[h';
$strNoPermission = 't@C %s ۑp[~bVEFuT[o[͎Ă܂B';
$strNoPhp = 'PHP R[h';
$strNoPrivileges = '';
$strNoQuery = 'SQL Ɖ';
$strNoRights = 'ݓĂȂ̂łɓ܂B';
$strNoRowsSelected = 's͑I܂łB';
$strNoSpace = 't@C %s ۑɂ͋󂫗eʂs\łB';
$strNoTablesFound = '݂ DB Ƀe[u͂܂B';
$strNoThemeSupport = 'e[}T|[gĂ܂Bݒƃe[}fBNg %s mFĂB';
$strNoUsersFound = 'Y[U[͌܂łB';
$strNoValidateSQL = 'SQL ؂XLbv';
$strNone = '';
$strNotNumber = '͐lł͂܂B';
$strNotOK = 'OK ł͂܂B';
$strNotSet = '<b>%s</b> e[uȂA%s ܂B';
$strNull = '̒l(NULL)';
$strNumSearchResultsInTable = '%s  <i>%s</i> e[uŌ܂B';
$strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ܂B';
$strNumTables = 'e[u';

$strOK = 'OK';
$strOftenQuotation = 'płBIvV́Achar ܂ varchar tB[ĥ" "ň͂܂Ă邱ƂӖ܂B';
$strOperations = '';
$strOperator = '';
$strOptimizeTable = 'e[uœK';
$strOptionalControls = 'ꕶ̓ǂݍ/݃IvV';
$strOptionally = 'IvV';
$strOr = '܂';
$strOverhead = 'I[o[wbh';
$strOverwriteExisting = 't@C݂ꍇ͏㏑';

$strPHP40203 = 'Ȃ̓}`oCg(mbstring)̈ɏdȃoÔ PHP 4.2.3 gĂ܂BPHP ̃oO|[g 19404 łBphpMyAdmin gȂÃo[W PHP ͂߂܂...ƌ patch ĂȂƓ܂B';
$strPHPVersion = 'PHP o[W';
$strPageNumber = 'y[Wԍ:';
$strPagesToBeFlushed = 'tbVꂽy[W';
$strPaperSize = 'TCY';
$strPartialText = 'Iȕ';
$strPassword = 'pX[h';
$strPasswordChanged = 'pX[h %s ύX܂B';
$strPasswordEmpty = 'pX[hłB';
$strPasswordHashing = 'pX[hnbV';
$strPasswordNotSame = 'pX[hł͂܂B';
$strPdfDbSchema = '"%s" f[^x[X - %s ł̐}';
$strPdfInvalidTblName = '"%s" e[u܂!';
$strPdfNoTables = 'e[u܂';
$strPerHour = '';
$strPerMinute = '/';
$strPerSecond = '/b';
$strPersian = 'yVA';
$strPhoneBook = 'db';
$strPhp = 'PHP R[h̍쐬';
$strPmaDocumentation = 'phpMyAdmin ̃hLg';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> K config t@C̒Őݒ肵Ă!';
$strPolish = '|[h';
$strPortrait = '|[gCg';
$strPos1 = 'ŏ';
$strPrevious = 'ȑO';
$strPrimary = 'v';
$strPrimaryKeyHasBeenDropped = 'L[폜܂B';
$strPrimaryKeyName = 'L[̖O... PRIMARY ł͂Ȃ΂܂B';
$strPrimaryKeyWarning = '("PRIMARY"͂傤ǎL[̖Oł͂Ȃ΂܂B';
$strPrint = '';
$strPrintView = 'p̕\';
$strPrintViewFull = 'r[ (SeLXg܂)';
$strPrivDescAllPrivileges = 'GRANT SĂ̓܂݂܂B';
$strPrivDescAlter = '݂e[u\̕ύX܂B';
$strPrivDescAlterDb = 'f[^x[X̃ftHgR[hяƍύX邱ƂƓlɊ̃e[u̍\ύX邱Ƃɂ܂B';
$strPrivDescAlterRoutine = 'XgAh[`̕ύXƔj܂B';
$strPrivDescCreateDb = 'Vf[^x[XAe[u̍쐬܂B';
$strPrivDescCreateRoutine = 'XgAh[`̍쐬܂B';
$strPrivDescCreateTbl = 'Ve[u̍쐬܂B';
$strPrivDescCreateTmpTable = 'e|[e[u̍쐬܂B';
$strPrivDescCreateUser = '[U[AJEg̍쐬EjE̕ύX܂B';
$strPrivDescCreateView = 'Vr[̍쐬܂B';
$strPrivDescDelete = 'f[^̍폜܂B';
$strPrivDescDropDb = 'f[^x[Xƃe[u̍폜܂B';
$strPrivDescDropTbl = 'e[u̍폜܂B';
$strPrivDescExecute = 'XgA[hvVW[̂܂; MySQLłł͈Ӗ܂B';
$strPrivDescExecute5 = 'XgAh[`̎s܂B';
$strPrivDescFile = 'f[^̃C|[gAf[^̃t@Cւ̃GNX|[g܂B';
$strPrivDescGrant = 'e[ũ[hȂɃ[U[A̒ǉ܂B';
$strPrivDescIndex = 'CfbNX̍쐬A폜܂B';
$strPrivDescInsert = 'f[^̑}Aւ܂B';
$strPrivDescLockTables = '݂̃Xbh̃bLOe[u܂B';
$strPrivDescMaxConnections = '1 ԓɐVڑ\Ȑ𐧌܂B';
$strPrivDescMaxQuestions = '1 ԓɃT[o[ɏƉ𑗂鐔𐧌܂B';
$strPrivDescMaxUpdates = '1 ԓɃe[uAf[^x[Xɑ΂Ă̕ύXR}h̐𐧌܂B';
$strPrivDescProcess3 = '̃[U[vZX~ł邱Ƃ܂B';
$strPrivDescProcess4 = 'vZXXg̊SȏƉ̕\܂B';
$strPrivDescReferences = ' MySQL o[Wł͈Ӗ܂B';
$strPrivDescReload = 'T[o[̃[hALbṼNA܂B';
$strPrivDescReplClient = 'X[u}X^[vł錠[U[ɗ^܂B';
$strPrivDescReplSlave = 'vP[VX[uKvłB';
$strPrivDescSelect = 'f[^̓ǂݏo';
$strPrivDescShowDb = 'f[^x[X̊SȃXgւ̃ANZX^܂B';
$strPrivDescShowView = 'Ɖ SHOW CREATE VIEW ̎s܂B';
$strPrivDescShutdown = 'T[o[̃Vbg_E܂B';
$strPrivDescSuper = 'ő̐ڑɒBĂڑ܂B̊Ǘ̓O[oϐ⑼[U[vZX̏Ił悤Ȑݒ肪KvłB';
$strPrivDescUpdate = 'f[^̏C܂B';
$strPrivDescUsage = '܂B';
$strPrivileges = '';
$strPrivilegesReloaded = '̓[h܂B';
$strProcesslist = 'vZXXg';
$strPutColNames = 'ŏ 1 sڂɃtB[hǉ';

$strQBE = 'Ɖ';
$strQBEDel = '폜';
$strQBEIns = '}';
$strQueryFrame = 'ƉEBhE';
$strQueryOnDb = 'f[^x[X SQL Ɖ <b>%s</b>:';
$strQuerySQLHistory = 'SQL ';
$strQueryStatistics = '<b>Ɖv</b>: N %s ƉT[o[ɑĂ܂B';
$strQueryTime = 'Ɖ̎s %01.4f b';
$strQueryType = 'Ɖ^Cv';
$strQueryWindowLock = 'EBhE̊O炱̏Ɖł܂B';

$strReType = 'ċL';
$strReadRequests = 'ǂݍ݃NGXg';
$strReceived = 'M';
$strRecords = 'R[h';
$strReferentialIntegrity = 'ڂ̃`FbN:';
$strRefresh = 'ĕ`';
$strRelationNotWorking = 'phpMyAdmin ̓Ǝ@\ł郊[V@\邽߂̃Ne[uLɂȂĂ܂Bɂ %s%s NbNČĂB';
$strRelationView = '[V\';
$strRelationalSchema = '[ViXL[}';
$strRelations = '[V';
$strRelationsForTable = 'RELATIONS FOR TABLE';
$strReloadFailed = 'MySQL ̃[hɎs܂B';
$strReloadMySQL = 'MySQL ̃[h';
$strReloadingThePrivileges = '[hłB';
$strRemoveSelectedUsers = 'Iꂽ[U[폜܂';
$strRenameDatabaseOK = 'f[^x[X %s  %s ɖ̕ύX܂B';
$strRenameTable = 'e[u̕ύX';
$strRenameTableOK = '%s  %s ɖOύX܂B';
$strRepairTable = 'e[u𕜋';
$strReplace = 'u';
$strReplaceNULLBy = 'NULL w̕Œu';
$strReplaceTable = 't@CŃe[uu';
$strReset = 'Zbg';
$strResourceLimits = '\[X̐';
$strRevoke = 'p~';
$strRevokeAndDelete = '[U[LȓSĔjč폜';
$strRevokeAndDeleteDescr = '[U[͓[h܂ USAGE ̂܂܂łB';
$strRevokeMessage = '%s ̓܂B';
$strRomanian = '[}jA';
$strRoutines = '[`';
$strRowLength = 's̒';
$strRowSize = ' s̃TCY ';
$strRows = 's';
$strRowsFrom = 'Jns';
$strRowsModeFlippedHorizontal = ' (]wb_[)';
$strRowsModeHorizontal = '';
$strRowsModeOptions = ': %s : %s 񂸂wb_[JԂ\';
$strRowsModeVertical = '';
$strRowsStatistic = 's̓v';
$strRunQuery = 'Ɖ̎s';
$strRunSQLQuery = 'f[^x[X %s SQL Ɖs';
$strRunning = 'słB %s';
$strRussian = 'VA';

$strSQL = 'SQL';
$strSQLExportCompatibility = 'SQL GNX|[g݊';
$strSQLExportType = 'GNX|[g`';
$strSQLOptions = 'SQL IvV';
$strSQLParserBugMessage = 'Ȃ SQL p[T[̃oO邩܂BȂ̖₢킹OɊm߂āAp~X}b`Ȃ`FbN܂傤B̑̎sɂ̓eLXgGAňpOɃoCi[R[htăt@CAbv[hĂ܂悤Ȍl܂B܂AȂ̖₢킹 MySQL ̃R}hCgĎƂł܂BMySQL T[o[͈ȉ̂悤ɃG[o܂Bɂ͖菕ł傤BR}hCł͐ĂA܂肪ꍇAp[T[sꍇɂ́Â SQL ₢킹ЂƂ̕Ɍ炵Ă݂ĉBĈȉ̃ZNVŃf[^؂ăoO񍐂𑗂ĉ:';
$strSQLParserUserError = 'Ȃ SQL ƉɃG[܂BMySQL T[o[͈ȉ̂悤ɃG[o܂Bɂ͖菕ł傤B';
$strSQLQuery = 's SQL Ɖ';
$strSQLResult = 'SQL ̌';
$strSQPBugInvalidIdentifer = 'F؂łB';
$strSQPBugUnclosedQuote = 'pĂ܂B';
$strSQPBugUnknownPunctuation = 'ȋǓ_łB';
$strSave = 'ۑ';
$strSaveOnServer = 'T[o[ %s fBNgɕۑ';
$strScaleFactorSmall = '1 y[Wɐ}\zu邽߂ɂ͑傫߂܂';
$strSearch = '';
$strSearchFormTitle = 'f[^x[X';
$strSearchInTables = 'e[u̎w:';
$strSearchNeedle = 'PA܂͒l (ChJ[h: "%"):';
$strSearchOption1 = 'ꂩ̒P܂';
$strSearchOption2 = 'SĂ̒P܂';
$strSearchOption3 = 'mȃt[Y';
$strSearchOption4 = 'K\';
$strSearchResultsFor = ' "<i>%s</i>" %s:';
$strSearchType = ':';
$strSecretRequired = 'ݒt@C͍͔閧pXt[YKvƂ܂(blowfish_secret)B';
$strSelectADb = 'f[^x[XIĂB';
$strSelectAll = 'SI';
$strSelectBinaryLog = 'IoCiO{';
$strSelectBinaryLog = 'IoCiO{';
$strSelectFields = 'tB[h̑I(1 ȏ):';
$strSelectNumRows = 'Ɖ';
$strSelectTables = 'e[ȗI';
$strSend = 't@Cŕۑ';
$strSent = 'M';
$strServer = 'T[o[';
$strServerChoice = 'T[o[̑I';
$strServerNotResponding = 'T[o[܂B';
$strServerStatus = '^C';
$strServerStatusUptime = 'MySQLT[o[ %s ԓ쒆ŁA%s ɋNĂ܂B';
$strServerTabProcesslist = 'vZX';
$strServerTabVariables = 'ϐ';
$strServerTrafficNotes = '<b>T[o[gtBbN</b>: ̃e[u MySQL T[o[NẴlbg[NgtBbN̓v\܂B';
$strServerVars = 'T[o[ϐƐݒl';
$strServerVersion = 'T[o[̃o[W';
$strSessionValue = 'ZbVl';
$strSetEnumVal = 'tB[h^Cv"enum""set"̏ꍇ͒l̃tH[}bggē͂Ă: \'a\',\'b\',\'c\'...<br />obNXbVu"\"v̓NI[gu"\'"v͂ƁAɃobNXbVtĉu: \'\\\\xyz\' or \'a\\\'b\'vB';
$strShow = '\';
$strShowAll = 'Sĕ\';
$strShowColor = 'F\';
$strShowDatadictAs = 'f[^tH[}bg';
$strShowFullQueries = 'tƉ\';
$strShowGrid = 'Obh̕\';
$strShowPHPInfo = 'PHP ';
$strShowTableDimension = 'e[ȗ傫\';
$strShowTables = 'e[u̕\';
$strShowThisQuery = ' sƉɕ\';
$strShowingRecords = 'R[h\';
$strSimplifiedChinese = 'ȑ̎';
$strSingly = '(1 )';
$strSize = 'TCY';
$strSlovak = 'XoLA';
$strSlovenian = 'XxjA';
$strSocketProblem = '(܂́A[J MySQL T[o[̃\Pbg͐mɐݒ肳܂)';
$strSort = '\[g';
$strSortByKey = 'L[Ń\[g';
$strSpaceUsage = 'fBXNgp';
$strSpanish = 'XyC';
$strSplitWordsWithSpace = 'eP̓Xy[X(" ")ŋ؂ĉB';
$strStatCheckTime = 'ŏI';
$strStatCreateTime = '쐬';
$strStatUpdateTime = 'ŏIXV';
$strStatement = 'Xe[gg';
$strStatus = '';
$strStorageEngine = 'Xg[WGW';
$strStorageEngines = 'Xg[WGW';
$strStrucCSV = 'CSV f[^';
$strStrucData = '\ƃf[^';
$strStrucDrop = 'uDROP TABLEvǉ';
$strStrucExcelCSV = 'MS Excel p CSV f[^';
$strStrucNativeExcel = '{ MS Excel f[^';
$strStrucOnly = '\̂';
$strStructPropose = 'e[u\̊mF';
$strStructure = '\';
$strSubmit = 's';
$strSuccess = 'SQL ƉɎs܂';
$strSum = 'v';
$strSwedish = 'XEF[f';
$strSwitchToDatabase = 'Rs[f[^x[Xɐ؂ւ';
$strSwitchToTable = 'Rs[e[uɐ؂ւ';

$strTable = 'e[u ';
$strTableComments = 'e[u̐';
$strTableEmpty = 'e[u͋łB';
$strTableHasBeenDropped = 'e[u %s 폜܂B';
$strTableHasBeenEmptied = 'e[u %s ɂ܂B';
$strTableHasBeenFlushed = 'e[u %s ̃LbVɂ܂B';
$strTableMaintenance = 'e[uǗ';
$strTableOfContents = 'e[u̓e';
$strTableOptions = 'e[uIvV';
$strTableStructure = 'e[u̍\';
$strTableType = 'e[ũ^Cv';
$strTables = '%se[u';
$strTakeIt = 'ɂ܂';
$strTblPrivileges = 'e[u ';
$strTextAreaLength = ' ׂ̏ł̃tB[h<br /> CłȂ\܂B';
$strThai = '^C';
$strTheContent = 't@C̃f[^}܂B';
$strTheContents = 't@C̃f[^ŁAIe[u̎vL[܂͗BȃL[Ɉvu܂B';
$strTheTerminator = 'tB[h̏I[LłB';
$strTheme = 'e[} / X^C';
$strThisHost = '̃zXg';
$strThisNotDirectory = '̓fBNgł͂܂';
$strThreadSuccessfullyKilled = 'Xbh %s ͏I܂B';
$strTime = '';
$strToggleScratchboard = 'gOXNb`{[h';
$strTotal = 'v';
$strTotalUC = 'v';
$strTraditionalChinese = '`IȒ';
$strTraditionalSpanish = '`IȃXyC';
$strTraffic = 'gtBbN';
$strTransformation_application_octetstream__download = 'tB[h̃oCif[^_E[h郊N\܂BЂƂ߂̃IvV̓oCit@C̃t@CłBӂ߂̃IvV̓t@C܂ރe[us̐tB[hłBӂ߂̃IvV񋟂ꍇAЂƂ߂̃IvV͋󕶎ɐݒ肷Kv܂B';
$strTransformation_image_jpeg__inline = 'NbN\ȃTlC\܂; IvV: widthEheight sNZŎw (̔䗦ۂ܂)';
$strTransformation_image_jpeg__link = '̉摜ւ̃N\ (Ⴆ blob 𒼐ڃ_E[h).';
$strTransformation_image_png__inline = 'uimage/jpeg: inlinevQƂĂB';
$strTransformation_text_plain__dateformat = 'TIMEATIMESTAMP邢DATETIMEtB[hŁA[J̓t\`pď܂B1 ڂ̃IvV̓^CX^vɉZItZbg(P:)ł(ftHg: 0)2 ڂ̃IvV́APHP  strftime()ŗp\ȃp[^[ł̂܂܂ȓt\`łB';
$strTransformation_text_plain__external = 'LINUX ̂: OAvP[VNAW͂tB[hf[^͂܂BAvP[V̕Wo͂Ԃ܂BftHg Tidy ŁAY HTML R[ho͂܂BZLeB̗RŁA蓮Ńt@Culibraries/text_plain__external.inc.phpvҏWAsc[}Ȃ΂Ȃ܂Bŏ̃IvV́AgpvO̐ŁA2 ڂ̃IvV̓vÕp[^łB3 ڂ̃IvV 1 ɐݒ肳ĂꍇAhtmlspecialchars() pďo͂ϊł傤(ftHg: 1)4  IvV 1 ɐݒ肳ĂꍇA֑hAoׂ͂ 1 sɌ邱Ƃۏ؂ł傤(ftHg: 1).';
$strTransformation_text_plain__formatted = 'tB[ȟ̏ۑ܂BGXP[vɏI܂B';
$strTransformation_text_plain__imagelink = '摜ƃNAt@C܂ރtB[h\܂; ЂƂ߂̃IvV "http://domain.com/" ̂悤ȐړŁAӂ߂̃IvV̓sNZw̕A݂߂͍łB';
$strTransformation_text_plain__link = 't@C܂ރtB[hAN\; ЂƂڂ̃IvV "http://domain.com/" ̂悤ȐړAڂ̃IvV̓Ñ^CgłB';
$strTransformation_text_plain__substr = '̈ꕔ̂ݕ\܂B1 ڂ̃IvV̓eLXg̏o͂ǂŊJn邩ItZbg`܂ (ftHǵu0vł)ڂ̃IvV͂ǂꂾ̃eLXgԂ̃ItZbgłB̏ꍇAc̃eLXgׂĕԂ܂BOڂ̃IvV́ÄꕔԂ鎞Aǂ̕o͂ɒǉ邩`܂B (ftHǵu...vł)';
$strTruncateQueries = 'Ɖ̕\؂l߂';
$strTurkish = 'gR';
$strType = 'tB[h^Cv';

$strUkrainian = 'ENCi';
$strUncheckAll = 'SẴ}[N폜';
$strUnicode = 'jR[h';
$strUnique = 'Ӑ';
$strUnknown = 's';
$strUnselectAll = 'S';
$strUpdComTab = 'Column_comments e[ũAbvO[h@̃hLgQƂĂB';
$strUpdatePrivMessage = '%s ̓XV܂B';
$strUpdateProfileMessage = 'vt@CXV܂B';
$strUpdateQuery = 'Ɖ̍XV';
$strUpgrade = '%s %s ڍsɃAbvO[hׂłB';
$strUsage = 'gp';
$strUseBackquotes = 'tNI[gŃe[utB[h͂';
$strUseHostTable = 'zXge[ug';
$strUseTabKey = 'll܂ňڂɂ TAB L[A͂ȏꏊłړɂ CTRL + J[\gp܂B';
$strUseTables = 'ge[u';
$strUseTextField = 'eLXgtB[hgp';
$strUseThisValue = '̒lgp';
$strUser = '[U[';
$strUserAlreadyExists = '[U[ %s ͊ɑ݂܂!';
$strUserEmpty = '[U[͋łB';
$strUserName = '[U[';
$strUserNotFound = 'Iꂽ[U[͓e[uɌ܂łB';
$strUserOverview = '[U[T';
$strUsersDeleted = 'Iꂽ[U[͍폜܂B';
$strUsersHavingAccessToDb = '[U[ &quot;%s&quot; ւ̃ANZXĂ܂B';

$strValidateSQL = 'SQL ̌';
$strValidatorError = 'SQL ̌؋@\ł܂B%sdocumentation%s ɋLqĂ悤 PHP gCuCXg[Ă邩`FbNĂB';
$strValue = 'l';
$strVar = 'ϐ';
$strVersionInformation = 'o[W';
$strView = 'r[';
$strViewDump = 'e[ũ_v(XL[})\';
$strViewDumpDB = 'DB ̃_v(XL[})\';
$strViewDumpDatabases = 'f[^x[X̃_vr[ (XL[})';
$strViewHasBeenDropped = 'r[ %s j܂B';

$strWebServerUploadDirectory = 'EFuT[o[ŃAbv[h';
$strWebServerUploadDirectoryError = 'Abv[hsfBNg܂B';
$strWelcome = '%s ւ悤';
$strWestEuropean = '[bp';
$strWildcard = 'ChJ[h';
$strWindowNotFound = '^[QbguEUEBhEXV邱Ƃł܂B炭eEBhEA邢̓uEU[̃ZLeBݒŁANXEBhE̍XVubNĂ܂B';
$strWithChecked = '`FbN̂:';
$strWriteRequests = '݃NGXg';
$strWritingCommentNotPossible = 'Rg݂̏Lł͂܂B';
$strWritingRelationNotPossible = '[V݂̏Lł͂܂B';
$strWrongUser = '[U[܂̓pX[h܂B<br />ANZX͋ۂ܂B';

$strXML = 'XML';
$strXkana = 'SpJi֕ϊ'; // convert to X208-kana

$strYes = '͂';

$strZeroRemovesTheLimit = ': IvV 0 ([)ɐݒ肷ƐȂȂ܂B';
$strZip = '"zip "';

// To translate:

$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate

$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate

$strLatchedPages = 'Latched pages';  //to translate

$strMIME_nodescription = '̕ϊɂ͗LȐ܂B<br />Please ask the author, what %s does.';//to translate
$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
$strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAMe[uɎgp MAX_ROWS IvVw肳Ȃꍇ̃oCgw̃ftHg|C^[TCYłB';
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate

$strTransformation_application_octetstream__hex = 'f[^ 16 i\łB';

$strInvalidFieldCount = 'e[u͏ȂƂЂƂ̃tB[hKvłB';
$strInvalidRowNumber = '%d ͐ȂsԍłB';
$strInvalidColumnCount = 'J 0 傫Ȃ΂܂B';
$strInvalidFieldAddCount = 'ȂƂЂƂ̃tB[hǉȂ΂Ȃ܂B';
$strAndThen = 'and then';  //to translate
?>
